==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/JobConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.JobConfigurationArgs.builder
import com.pulumi.azurenative.app.kotlin.enums.TriggerType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Non versioned Container Apps Job configuration properties
 * @property eventTriggerConfig Trigger configuration of an event driven job.
 * @property manualTriggerConfig Manual trigger configuration for a single execution job. Properties replicaCompletionCount and parallelism would be set to 1 by default
 * @property registries Collection of private container registry credentials used by a Container apps job
 * @property replicaRetryLimit Maximum number of retries before failing the job.
 * @property replicaTimeout Maximum number of seconds a replica is allowed to run.
 * @property scheduleTriggerConfig Cron formatted repeating trigger schedule ("* * * * *") for cronjobs. Properties completions and parallelism would be set to 1 by default
 * @property secrets Collection of secrets used by a Container Apps Job
 * @property triggerType Trigger type of the job
 */
public data class JobConfigurationArgs(
    public val eventTriggerConfig: Output<JobConfigurationEventTriggerConfigArgs>? = null,
    public val manualTriggerConfig: Output<JobConfigurationManualTriggerConfigArgs>? = null,
    public val registries: Output<List<RegistryCredentialsArgs>>? = null,
    public val replicaRetryLimit: Output<Int>? = null,
    public val replicaTimeout: Output<Int>,
    public val scheduleTriggerConfig: Output<JobConfigurationScheduleTriggerConfigArgs>? = null,
    public val secrets: Output<List<SecretArgs>>? = null,
    public val triggerType: Output<Either<String, TriggerType>>,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.JobConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.JobConfigurationArgs =
        com.pulumi.azurenative.app.inputs.JobConfigurationArgs.builder()
            .eventTriggerConfig(
                eventTriggerConfig?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .manualTriggerConfig(
                manualTriggerConfig?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .registries(
                registries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .replicaRetryLimit(replicaRetryLimit?.applyValue({ args0 -> args0 }))
            .replicaTimeout(replicaTimeout.applyValue({ args0 -> args0 }))
            .scheduleTriggerConfig(
                scheduleTriggerConfig?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .secrets(
                secrets?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .triggerType(
                triggerType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [JobConfigurationArgs].
 */
@PulumiTagMarker
public class JobConfigurationArgsBuilder internal constructor() {
    private var eventTriggerConfig: Output<JobConfigurationEventTriggerConfigArgs>? = null

    private var manualTriggerConfig: Output<JobConfigurationManualTriggerConfigArgs>? = null

    private var registries: Output<List<RegistryCredentialsArgs>>? = null

    private var replicaRetryLimit: Output<Int>? = null

    private var replicaTimeout: Output<Int>? = null

    private var scheduleTriggerConfig: Output<JobConfigurationScheduleTriggerConfigArgs>? = null

    private var secrets: Output<List<SecretArgs>>? = null

    private var triggerType: Output<Either<String, TriggerType>>? = null

    /**
     * @param value Trigger configuration of an event driven job.
     */
    @JvmName("dwdvdmdkgcyraeqf")
    public suspend fun eventTriggerConfig(`value`: Output<JobConfigurationEventTriggerConfigArgs>) {
        this.eventTriggerConfig = value
    }

    /**
     * @param value Manual trigger configuration for a single execution job. Properties replicaCompletionCount and parallelism would be set to 1 by default
     */
    @JvmName("pyafhpwsvonwuwnk")
    public suspend fun manualTriggerConfig(`value`: Output<JobConfigurationManualTriggerConfigArgs>) {
        this.manualTriggerConfig = value
    }

    /**
     * @param value Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("qdbrtlnvyxbstwid")
    public suspend fun registries(`value`: Output<List<RegistryCredentialsArgs>>) {
        this.registries = value
    }

    @JvmName("yjnwmtxxccfwbjji")
    public suspend fun registries(vararg values: Output<RegistryCredentialsArgs>) {
        this.registries = Output.all(values.asList())
    }

    /**
     * @param values Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("uxnbptifxlhuuvbq")
    public suspend fun registries(values: List<Output<RegistryCredentialsArgs>>) {
        this.registries = Output.all(values)
    }

    /**
     * @param value Maximum number of retries before failing the job.
     */
    @JvmName("qgujdrxruekpjjmr")
    public suspend fun replicaRetryLimit(`value`: Output<Int>) {
        this.replicaRetryLimit = value
    }

    /**
     * @param value Maximum number of seconds a replica is allowed to run.
     */
    @JvmName("tutmdaiducfrkvib")
    public suspend fun replicaTimeout(`value`: Output<Int>) {
        this.replicaTimeout = value
    }

    /**
     * @param value Cron formatted repeating trigger schedule ("* * * * *") for cronjobs. Properties completions and parallelism would be set to 1 by default
     */
    @JvmName("sbprcpworsekxkuy")
    public suspend
    fun scheduleTriggerConfig(`value`: Output<JobConfigurationScheduleTriggerConfigArgs>) {
        this.scheduleTriggerConfig = value
    }

    /**
     * @param value Collection of secrets used by a Container Apps Job
     */
    @JvmName("tgsskniatcdhcurl")
    public suspend fun secrets(`value`: Output<List<SecretArgs>>) {
        this.secrets = value
    }

    @JvmName("xfxhjalaiwqdhnej")
    public suspend fun secrets(vararg values: Output<SecretArgs>) {
        this.secrets = Output.all(values.asList())
    }

    /**
     * @param values Collection of secrets used by a Container Apps Job
     */
    @JvmName("xcdnftcfvsegwsmf")
    public suspend fun secrets(values: List<Output<SecretArgs>>) {
        this.secrets = Output.all(values)
    }

    /**
     * @param value Trigger type of the job
     */
    @JvmName("mtiipkcxjnbjwvyj")
    public suspend fun triggerType(`value`: Output<Either<String, TriggerType>>) {
        this.triggerType = value
    }

    /**
     * @param value Trigger configuration of an event driven job.
     */
    @JvmName("qfdomhlidltfmcrt")
    public suspend fun eventTriggerConfig(`value`: JobConfigurationEventTriggerConfigArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eventTriggerConfig = mapped
    }

    /**
     * @param argument Trigger configuration of an event driven job.
     */
    @JvmName("nydtxbnfttqwhspl")
    public suspend
    fun eventTriggerConfig(argument: suspend JobConfigurationEventTriggerConfigArgsBuilder.() -> Unit) {
        val toBeMapped = JobConfigurationEventTriggerConfigArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.eventTriggerConfig = mapped
    }

    /**
     * @param value Manual trigger configuration for a single execution job. Properties replicaCompletionCount and parallelism would be set to 1 by default
     */
    @JvmName("mshqosdsnokvxmpd")
    public suspend fun manualTriggerConfig(`value`: JobConfigurationManualTriggerConfigArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.manualTriggerConfig = mapped
    }

    /**
     * @param argument Manual trigger configuration for a single execution job. Properties replicaCompletionCount and parallelism would be set to 1 by default
     */
    @JvmName("cskmcfkbcqlytyxh")
    public suspend
    fun manualTriggerConfig(argument: suspend JobConfigurationManualTriggerConfigArgsBuilder.() -> Unit) {
        val toBeMapped = JobConfigurationManualTriggerConfigArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.manualTriggerConfig = mapped
    }

    /**
     * @param value Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("aydlsjikrueekhjc")
    public suspend fun registries(`value`: List<RegistryCredentialsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registries = mapped
    }

    /**
     * @param argument Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("wonefxlvldcawevr")
    public suspend fun registries(argument: List<suspend RegistryCredentialsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RegistryCredentialsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.registries = mapped
    }

    /**
     * @param argument Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("sxpavxywtokrghrf")
    public suspend fun registries(
        vararg
        argument: suspend RegistryCredentialsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RegistryCredentialsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.registries = mapped
    }

    /**
     * @param argument Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("hqpbopmjedchdyim")
    public suspend fun registries(argument: suspend RegistryCredentialsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(RegistryCredentialsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.registries = mapped
    }

    /**
     * @param values Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("fsdpjpmbgpietalx")
    public suspend fun registries(vararg values: RegistryCredentialsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.registries = mapped
    }

    /**
     * @param value Maximum number of retries before failing the job.
     */
    @JvmName("kadanrnuxjckiiim")
    public suspend fun replicaRetryLimit(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.replicaRetryLimit = mapped
    }

    /**
     * @param value Maximum number of seconds a replica is allowed to run.
     */
    @JvmName("bkkeyihxkmvrhwev")
    public suspend fun replicaTimeout(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.replicaTimeout = mapped
    }

    /**
     * @param value Cron formatted repeating trigger schedule ("* * * * *") for cronjobs. Properties completions and parallelism would be set to 1 by default
     */
    @JvmName("lmskklphtjqgukpn")
    public suspend fun scheduleTriggerConfig(`value`: JobConfigurationScheduleTriggerConfigArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scheduleTriggerConfig = mapped
    }

    /**
     * @param argument Cron formatted repeating trigger schedule ("* * * * *") for cronjobs. Properties completions and parallelism would be set to 1 by default
     */
    @JvmName("yhyxihobbwhvkiqm")
    public suspend
    fun scheduleTriggerConfig(argument: suspend JobConfigurationScheduleTriggerConfigArgsBuilder.() -> Unit) {
        val toBeMapped = JobConfigurationScheduleTriggerConfigArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.scheduleTriggerConfig = mapped
    }

    /**
     * @param value Collection of secrets used by a Container Apps Job
     */
    @JvmName("dehkjaxnucfjptfu")
    public suspend fun secrets(`value`: List<SecretArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secrets = mapped
    }

    /**
     * @param argument Collection of secrets used by a Container Apps Job
     */
    @JvmName("lfucqvqeqorgytvk")
    public suspend fun secrets(argument: List<suspend SecretArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { SecretArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.secrets = mapped
    }

    /**
     * @param argument Collection of secrets used by a Container Apps Job
     */
    @JvmName("pdlmtevhwcgabugc")
    public suspend fun secrets(vararg argument: suspend SecretArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { SecretArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.secrets = mapped
    }

    /**
     * @param argument Collection of secrets used by a Container Apps Job
     */
    @JvmName("evbpvicebagutdfw")
    public suspend fun secrets(argument: suspend SecretArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SecretArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.secrets = mapped
    }

    /**
     * @param values Collection of secrets used by a Container Apps Job
     */
    @JvmName("wwtgxetvrcnqlitq")
    public suspend fun secrets(vararg values: SecretArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secrets = mapped
    }

    /**
     * @param value Trigger type of the job
     */
    @JvmName("vpanmsdesujdglan")
    public suspend fun triggerType(`value`: Either<String, TriggerType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.triggerType = mapped
    }

    /**
     * @param value Trigger type of the job
     */
    @JvmName("neqobtngaoqnasnd")
    public fun triggerType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TriggerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.triggerType = mapped
    }

    /**
     * @param value Trigger type of the job
     */
    @JvmName("xxnciujbwdvrmncl")
    public fun triggerType(`value`: TriggerType) {
        val toBeMapped = Either.ofRight<String, TriggerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.triggerType = mapped
    }

    internal fun build(): JobConfigurationArgs = JobConfigurationArgs(
        eventTriggerConfig = eventTriggerConfig,
        manualTriggerConfig = manualTriggerConfig,
        registries = registries,
        replicaRetryLimit = replicaRetryLimit,
        replicaTimeout = replicaTimeout ?: throw PulumiNullFieldException("replicaTimeout"),
        scheduleTriggerConfig = scheduleTriggerConfig,
        secrets = secrets,
        triggerType = triggerType ?: throw PulumiNullFieldException("triggerType"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/JobConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.JobConfigurationArgs.builder
import com.pulumi.azurenative.app.kotlin.enums.TriggerType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Non versioned Container Apps Job configuration properties
 * @property eventTriggerConfig Trigger configuration of an event driven job.
 * @property manualTriggerConfig Manual trigger configuration for a single execution job. Properties replicaCompletionCount and parallelism would be set to 1 by default
 * @property registries Collection of private container registry credentials used by a Container apps job
 * @property replicaRetryLimit Maximum number of retries before failing the job.
 * @property replicaTimeout Maximum number of seconds a replica is allowed to run.
 * @property scheduleTriggerConfig Cron formatted repeating trigger schedule ("* * * * *") for cronjobs. Properties completions and parallelism would be set to 1 by default
 * @property secrets Collection of secrets used by a Container Apps Job
 * @property triggerType Trigger type of the job
 */
public data class JobConfigurationArgs(
    public val eventTriggerConfig: Output<JobConfigurationEventTriggerConfigArgs>? = null,
    public val manualTriggerConfig: Output<JobConfigurationManualTriggerConfigArgs>? = null,
    public val registries: Output<List<RegistryCredentialsArgs>>? = null,
    public val replicaRetryLimit: Output<Int>? = null,
    public val replicaTimeout: Output<Int>,
    public val scheduleTriggerConfig: Output<JobConfigurationScheduleTriggerConfigArgs>? = null,
    public val secrets: Output<List<SecretArgs>>? = null,
    public val triggerType: Output<Either<String, TriggerType>>,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.JobConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.JobConfigurationArgs =
        com.pulumi.azurenative.app.inputs.JobConfigurationArgs.builder()
            .eventTriggerConfig(
                eventTriggerConfig?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .manualTriggerConfig(
                manualTriggerConfig?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .registries(
                registries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .replicaRetryLimit(replicaRetryLimit?.applyValue({ args0 -> args0 }))
            .replicaTimeout(replicaTimeout.applyValue({ args0 -> args0 }))
            .scheduleTriggerConfig(
                scheduleTriggerConfig?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .secrets(
                secrets?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .triggerType(
                triggerType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [JobConfigurationArgs].
 */
@PulumiTagMarker
public class JobConfigurationArgsBuilder internal constructor() {
    private var eventTriggerConfig: Output<JobConfigurationEventTriggerConfigArgs>? = null

    private var manualTriggerConfig: Output<JobConfigurationManualTriggerConfigArgs>? = null

    private var registries: Output<List<RegistryCredentialsArgs>>? = null

    private var replicaRetryLimit: Output<Int>? = null

    private var replicaTimeout: Output<Int>? = null

    private var scheduleTriggerConfig: Output<JobConfigurationScheduleTriggerConfigArgs>? = null

    private var secrets: Output<List<SecretArgs>>? = null

    private var triggerType: Output<Either<String, TriggerType>>? = null

    /**
     * @param value Trigger configuration of an event driven job.
     */
    @JvmName("gjhlwrxucwmmeelo")
    public suspend fun eventTriggerConfig(`value`: Output<JobConfigurationEventTriggerConfigArgs>) {
        this.eventTriggerConfig = value
    }

    /**
     * @param value Manual trigger configuration for a single execution job. Properties replicaCompletionCount and parallelism would be set to 1 by default
     */
    @JvmName("pfkhfearfnpujtnn")
    public suspend fun manualTriggerConfig(`value`: Output<JobConfigurationManualTriggerConfigArgs>) {
        this.manualTriggerConfig = value
    }

    /**
     * @param value Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("kigoicxpeyxdxcpq")
    public suspend fun registries(`value`: Output<List<RegistryCredentialsArgs>>) {
        this.registries = value
    }

    @JvmName("ypafkegkxulybpqt")
    public suspend fun registries(vararg values: Output<RegistryCredentialsArgs>) {
        this.registries = Output.all(values.asList())
    }

    /**
     * @param values Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("hheqkokfoprkgibx")
    public suspend fun registries(values: List<Output<RegistryCredentialsArgs>>) {
        this.registries = Output.all(values)
    }

    /**
     * @param value Maximum number of retries before failing the job.
     */
    @JvmName("aubrfasdykofbytb")
    public suspend fun replicaRetryLimit(`value`: Output<Int>) {
        this.replicaRetryLimit = value
    }

    /**
     * @param value Maximum number of seconds a replica is allowed to run.
     */
    @JvmName("wmuwpnqygxsykarq")
    public suspend fun replicaTimeout(`value`: Output<Int>) {
        this.replicaTimeout = value
    }

    /**
     * @param value Cron formatted repeating trigger schedule ("* * * * *") for cronjobs. Properties completions and parallelism would be set to 1 by default
     */
    @JvmName("ldtesmuowujncpiy")
    public suspend
    fun scheduleTriggerConfig(`value`: Output<JobConfigurationScheduleTriggerConfigArgs>) {
        this.scheduleTriggerConfig = value
    }

    /**
     * @param value Collection of secrets used by a Container Apps Job
     */
    @JvmName("fegttcnwvodjymtx")
    public suspend fun secrets(`value`: Output<List<SecretArgs>>) {
        this.secrets = value
    }

    @JvmName("rmrqdnrvymjyjmjl")
    public suspend fun secrets(vararg values: Output<SecretArgs>) {
        this.secrets = Output.all(values.asList())
    }

    /**
     * @param values Collection of secrets used by a Container Apps Job
     */
    @JvmName("gdkjvdnqusdlbdjs")
    public suspend fun secrets(values: List<Output<SecretArgs>>) {
        this.secrets = Output.all(values)
    }

    /**
     * @param value Trigger type of the job
     */
    @JvmName("qililaffgpavhaql")
    public suspend fun triggerType(`value`: Output<Either<String, TriggerType>>) {
        this.triggerType = value
    }

    /**
     * @param value Trigger configuration of an event driven job.
     */
    @JvmName("btndtbhkrswbslvf")
    public suspend fun eventTriggerConfig(`value`: JobConfigurationEventTriggerConfigArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eventTriggerConfig = mapped
    }

    /**
     * @param argument Trigger configuration of an event driven job.
     */
    @JvmName("udpcramhrqwmisqy")
    public suspend
    fun eventTriggerConfig(argument: suspend JobConfigurationEventTriggerConfigArgsBuilder.() -> Unit) {
        val toBeMapped = JobConfigurationEventTriggerConfigArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.eventTriggerConfig = mapped
    }

    /**
     * @param value Manual trigger configuration for a single execution job. Properties replicaCompletionCount and parallelism would be set to 1 by default
     */
    @JvmName("vhbioygvibgaftbu")
    public suspend fun manualTriggerConfig(`value`: JobConfigurationManualTriggerConfigArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.manualTriggerConfig = mapped
    }

    /**
     * @param argument Manual trigger configuration for a single execution job. Properties replicaCompletionCount and parallelism would be set to 1 by default
     */
    @JvmName("wdnsfwnptcnqkubq")
    public suspend
    fun manualTriggerConfig(argument: suspend JobConfigurationManualTriggerConfigArgsBuilder.() -> Unit) {
        val toBeMapped = JobConfigurationManualTriggerConfigArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.manualTriggerConfig = mapped
    }

    /**
     * @param value Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("nristmgkfxkvryvs")
    public suspend fun registries(`value`: List<RegistryCredentialsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registries = mapped
    }

    /**
     * @param argument Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("sgddgruqnddjbbno")
    public suspend fun registries(argument: List<suspend RegistryCredentialsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RegistryCredentialsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.registries = mapped
    }

    /**
     * @param argument Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("tkksxaicfysmgrri")
    public suspend fun registries(
        vararg
        argument: suspend RegistryCredentialsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RegistryCredentialsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.registries = mapped
    }

    /**
     * @param argument Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("oeawslsgmwxwoyum")
    public suspend fun registries(argument: suspend RegistryCredentialsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(RegistryCredentialsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.registries = mapped
    }

    /**
     * @param values Collection of private container registry credentials used by a Container apps job
     */
    @JvmName("mugqopvaaajyhxek")
    public suspend fun registries(vararg values: RegistryCredentialsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.registries = mapped
    }

    /**
     * @param value Maximum number of retries before failing the job.
     */
    @JvmName("vitxgscnahduoqfi")
    public suspend fun replicaRetryLimit(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.replicaRetryLimit = mapped
    }

    /**
     * @param value Maximum number of seconds a replica is allowed to run.
     */
    @JvmName("ualtubaiutsyapfh")
    public suspend fun replicaTimeout(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.replicaTimeout = mapped
    }

    /**
     * @param value Cron formatted repeating trigger schedule ("* * * * *") for cronjobs. Properties completions and parallelism would be set to 1 by default
     */
    @JvmName("aukrwonioebsuxqg")
    public suspend fun scheduleTriggerConfig(`value`: JobConfigurationScheduleTriggerConfigArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scheduleTriggerConfig = mapped
    }

    /**
     * @param argument Cron formatted repeating trigger schedule ("* * * * *") for cronjobs. Properties completions and parallelism would be set to 1 by default
     */
    @JvmName("lhkbaopvaopmtiir")
    public suspend
    fun scheduleTriggerConfig(argument: suspend JobConfigurationScheduleTriggerConfigArgsBuilder.() -> Unit) {
        val toBeMapped = JobConfigurationScheduleTriggerConfigArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.scheduleTriggerConfig = mapped
    }

    /**
     * @param value Collection of secrets used by a Container Apps Job
     */
    @JvmName("ydsqgugxtnclfqst")
    public suspend fun secrets(`value`: List<SecretArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secrets = mapped
    }

    /**
     * @param argument Collection of secrets used by a Container Apps Job
     */
    @JvmName("hfpmnynxbqsugwyu")
    public suspend fun secrets(argument: List<suspend SecretArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { SecretArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.secrets = mapped
    }

    /**
     * @param argument Collection of secrets used by a Container Apps Job
     */
    @JvmName("ogkwymyttneqxsjn")
    public suspend fun secrets(vararg argument: suspend SecretArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { SecretArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.secrets = mapped
    }

    /**
     * @param argument Collection of secrets used by a Container Apps Job
     */
    @JvmName("inkalugcqdnbgivw")
    public suspend fun secrets(argument: suspend SecretArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SecretArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.secrets = mapped
    }

    /**
     * @param values Collection of secrets used by a Container Apps Job
     */
    @JvmName("ldxxeveeubpgqxcf")
    public suspend fun secrets(vararg values: SecretArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secrets = mapped
    }

    /**
     * @param value Trigger type of the job
     */
    @JvmName("ylqwjckjjylicqle")
    public suspend fun triggerType(`value`: Either<String, TriggerType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.triggerType = mapped
    }

    /**
     * @param value Trigger type of the job
     */
    @JvmName("ckulxgmllmjdnyeg")
    public fun triggerType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TriggerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.triggerType = mapped
    }

    /**
     * @param value Trigger type of the job
     */
    @JvmName("vchhkqnlvujnqdgv")
    public fun triggerType(`value`: TriggerType) {
        val toBeMapped = Either.ofRight<String, TriggerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.triggerType = mapped
    }

    internal fun build(): JobConfigurationArgs = JobConfigurationArgs(
        eventTriggerConfig = eventTriggerConfig,
        manualTriggerConfig = manualTriggerConfig,
        registries = registries,
        replicaRetryLimit = replicaRetryLimit,
        replicaTimeout = replicaTimeout ?: throw PulumiNullFieldException("replicaTimeout"),
        scheduleTriggerConfig = scheduleTriggerConfig,
        secrets = secrets,
        triggerType = triggerType ?: throw PulumiNullFieldException("triggerType"),
    )
}
